' sort sheets numerically ignoring alpha chars

' This example demonstrates one method that will allow you to 
' sort all of the drawing sheets in the current display part using
' only the numeric characters in the sheet names.
'
' This way if you have a lot of sheets, for example, you will not 
' see Sheet 10 ordered immediately after Sheet 1.
'
' It will not matter if all of the sheets have the same prefix or 
' suffix.  You can have Sheet 1 and Sh2 and Sht 3, and they 
' will be sorted based only on the numeric characters.
'
' This can be useful if sheets have been renamed, and you want
' to do something with them in numerical order, such as 
' plotting them, or exporting them to a PDF.
'
' Note that if you have two sheets whose names get evaluated 
' to the same numeric value, such as Sheet 11 and Sheet 1_1, 
' then the order for those is not guaranteed.

Option Strict Off
Imports System
Imports System.Collections

Imports NXOpen
Imports NXOpen.Drawings

Module sort_sheets_numerically_ignoring_alpha_chars

    Dim theSession As Session = Session.GetSession()

    Sub Main(ByVal args As String())

        Dim dp As Part = theSession.Parts.Display()

        Dim drawingSheets As DrawingSheet() = dp.DrawingSheets.ToArray()

        If drawingSheets.Length() > 0 Then
            Echo("Sheets found: " & drawingSheets.Length().ToString())
        End If
        Echo("Initial order from Collection:")

        For Each thisSheet As DrawingSheet In drawingSheets
            Echo(thisSheet.Name())
        Next

        Echo("  ")
        Echo("Order of sheets after sorting:")

        sortSheets(drawingSheets)

        For Each thisSheet As DrawingSheet In drawingSheets
            Echo(thisSheet.Name())
        Next

    End Sub

    Public Sub sortSheets(ByVal ds() As DrawingSheet)

        If ds.GetUpperBound(0) = 0 Then
            Return
        End If
        Dim counter As Integer = 0

        Dim nums(ds.GetUpperBound(0)) As Integer

        For Each thisDwg As DrawingSheet In ds
            Dim tmpStr As String = strip_non_numeric_chars(thisDwg.Name())
            nums(counter) = Val(tmpStr)
            counter += 1
        Next

        Array.Sort(nums, ds)

    End Sub

    Public Function strip_non_numeric_chars(ByRef s As String) As String

        Dim numString As String = ""

        For inx As Integer = 0 To s.Length() - 1
            If Char.IsDigit(s, inx) Then
                numString = numString & s.Substring(inx, 1)
            End If
        Next

        Return numString

    End Function

    Sub Echo(ByVal output As String)

        theSession.ListingWindow.Open()
        theSession.ListingWindow.WriteLine(output)
        theSession.LogFile.WriteLine(output)

    End Sub

    Public Function GetUnloadOption(ByVal dummy As String) As Integer

        Return Session.LibraryUnloadOption.Immediately

    End Function

End Module